<?php

global $newtask_text;
$newtask_text = array (

'createnewtask'     =>  'Neue Aufgabe in diesem Projekt anlegen:',
'summary'           =>  'Zusammenfassung',
'tasktype'          =>  'Aufgabentyp',
'category'          =>  'Kategorie',
'status'            =>  'Status',
'assignedto'        =>  'Zugeteilt',
'noone'             =>  'Niemand',
'operatingsystem'   =>  'Betriebssystem',
'severity'          =>  'Schweregrad',
'reportedversion'   =>  'Berichtete Version',
'dueinversion'      =>  'Fällig in Version',
'details'           =>  'Details',
'addanother'        =>  'Weitere Aufgabe nach dieser hinzufügen',
'addthistask'       =>  'Aufgabe hinzufügen',
'nopermission'      =>  'Sie sind nicht berechtigt, diese Seite zu verwenden',

// Added in version 0.9.5

'notifyme'          =>  'Automatische Benachrichtigung bei Änderungen an dieser Aufgabe',
'priority'			=>	'Priorität',
'undecided'			=>	'Unbestimmt',

);
?>
